@@ -81,8 +81,9 @@ typedef enum
     GNC_TREE_MODEL_ACCOUNT_COL_TAX_INFO_SUB_ACCT,
     GNC_TREE_MODEL_ACCOUNT_COL_HIDDEN,
     GNC_TREE_MODEL_ACCOUNT_COL_PLACEHOLDER,
+    GNC_TREE_MODEL_ACCOUNT_COL_OPENING_BALANCE,
 
-    GNC_TREE_MODEL_ACCOUNT_COL_LAST_VISIBLE = GNC_TREE_MODEL_ACCOUNT_COL_PLACEHOLDER,
+    GNC_TREE_MODEL_ACCOUNT_COL_LAST_VISIBLE = GNC_TREE_MODEL_ACCOUNT_COL_OPENING_BALANCE,
 
     /* internal hidden columns */
     GNC_TREE_MODEL_ACCOUNT_COL_COLOR_PRESENT,
