@@ -32,12 +32,14 @@
 (use-modules (ice-9 match))
 (use-modules (srfi srfi-1))
 (use-modules (srfi srfi-9))
+(use-modules (srfi srfi-26))
 (use-modules (gnucash report report-register-hooks))
 (use-modules (gnucash report html-style-sheet))
 (use-modules (gnucash report html-document))
 (use-modules (gnucash report html-utilities))
 
-(load-and-reexport (sw_report))
+(load-and-reexport (sw_report)
+                   (sw_engine))
 
 (export <report>)
 (export gnc:all-report-template-guids)
@@ -209,16 +211,15 @@
   (G_ "One of your reports has a report-guid that is a duplicate. Please check the report system, especially your saved reports, for a report with this report-guid: "))
 (define rpterr-guid1 (G_ "Wrong report definition: "))
 (define rpterr-guid2 (G_ " Report is missing a GUID."))
-(define rptwarn-legacy
-  (G_ "Some reports stored in a legacy format were found. This format is not supported anymore so these reports may not have been restored properly."))
+
 (define (gui-error str)
   (if (gnucash-ui-is-running)
       (gnc-error-dialog '() str)
-      (gnc:error "report-impl.scm error: " str)))
+      (gnc:error "report-core.scm error: " str)))
 (define (gui-warning str)
   (if (gnucash-ui-is-running)
       (gnc-warning-dialog '() str)
-      (gnc:warn "report-impl.scm warning: " str)))
+      (gnc:warn "report-core.scm warning: " str)))
 (define (gui-error-missing-template template-name)
   (gui-error
    (string-append
@@ -237,6 +238,7 @@ not found.")))
   (define report-rec (make-report-template))
   (define allowable-fields (record-type-fields <report-template>))
   (define (not-a-field? fld) (not (memq fld allowable-fields)))
+  (define (xor . args) (fold (lambda (a b) (if a (if b #f a) b)) #f args))
 
   (let loop ((args args))
     (match args
@@ -252,6 +254,11 @@ not found.")))
           ((hash-ref *gnc:_report-templates_* report-guid)
            (gui-error (string-append rpterr-dupe report-guid)))
 
+          ;; has export-type but no export-thunk. or vice versa.
+          ((xor (gnc:report-template-export-thunk report-rec)
+                (gnc:report-template-export-types report-rec))
+           (gui-error (format #f "Export needs both thunk and types: ~a" report-guid)))
+
           ;; good: new report definition, store into report-templates hash
           (else
            (hash-set! *gnc:_report-templates_* report-guid report-rec)))))
@@ -295,9 +302,7 @@ not found.")))
            (lambda (ss)
              (vector
               (string->symbol (gnc:html-style-sheet-name ss))
-              (gnc:html-style-sheet-name ss)
-              (string-append (gnc:html-style-sheet-name ss)
-                             " " (G_ "stylesheet."))))
+              (gnc:html-style-sheet-name ss)))
            (gnc:get-html-style-sheets)))))
 
     (let ((options (if (procedure? generator)
@@ -811,6 +816,17 @@ not found.")))
 ;; gnucash-cli helper and exported functions
 ;;
 
+(define (show-selected-reports pred? port)
+  (for-each
+   (lambda (template)
+     (format port "* ~a ~a\n"
+             (if (gnc:report-template-parent-type template) "C" " ")
+             (gnc:report-template-name template)))
+   (sort (hash-fold (lambda (k v p) (if (pred? v) (cons v p) p)) '()
+                    *gnc:_report-templates_*)
+         (lambda (a b) (gnc:string-locale<? (gnc:report-template-name a)
+                                            (gnc:report-template-name b))))))
+
 (define (stderr-log tmpl . args)
   (apply format (current-error-port) tmpl args)
   #f)
@@ -825,8 +841,10 @@ not found.")))
          (export-types (gnc:report-template-export-types template)))
 
     (cond
-     ((not export-thunk) (stderr-log "Report ~s has no export code\n" report))
-     ((not export-types) (stderr-log "Report ~s has no export-types\n" report))
+     ((not export-thunk)
+      (stderr-log "Only the following reports have export code:\n")
+      (show-selected-reports gnc:report-template-export-thunk (current-error-port))
+      (stderr-log "Use -R show to describe report\n"))
      ((not (assoc export-type export-types))
       (stderr-log "Export-type disallowed: ~a. Allowed types: ~a\n"
                   export-type (string-join (map car export-types) ", ")))
@@ -846,17 +864,7 @@ not found.")))
        '() *gnc:_report-templates_*)))
 
 (define-public (gnc:cmdline-report-list port)
-  (for-each
-   (lambda (template)
-     (format port "* ~a ~a\n"
-             (if (gnc:report-template-parent-type template) "C" " ")
-             (gnc:report-template-name template)))
-   (sort (hash-fold
-          (lambda (k v p) (if (gnc:report-template-in-menu? v) (cons v p) p))
-          '() *gnc:_report-templates_*)
-         (lambda (a b)
-           (gnc:string-locale<? (gnc:report-template-name a)
-                                (gnc:report-template-name b))))))
+  (show-selected-reports gnc:report-template-in-menu? port))
 
 (define-public (gnc:cmdline-report-show report port)
   (let ((templates (reportname->templates report)))
