@@ -239,8 +239,6 @@
                                       optname-report-commodity))
          (price-source (get-option pagename-commodities
                                    optname-price-source))
-         (show-fcur? (get-option pagename-commodities
-                                 optname-show-foreign))
          (show-rates? (get-option pagename-commodities
                                   optname-show-rates))
          (use-rules? (get-option gnc:pagename-display
@@ -280,7 +278,9 @@
 	 (end-exchange-fn
 	  (gnc:case-exchange-fn
 	   price-source report-commodity end-date))
-	 )
+
+         (start-price-fn (gnc:case-price-fn price-source report-commodity start-date))
+         (end-price-fn (gnc:case-price-fn price-source report-commodity end-date)))
 
     (define (unrealized-gains-at-date book-balance exchange-fn date)
       (define cost-fn
@@ -496,10 +496,10 @@
 		   (headers (list
 			     (qof-print-date start-date-printable)
 			     (qof-print-date end-date)))
-		   (then (gnc:html-make-exchangerates
-			  report-commodity start-exchange-fn accounts))
-		   (now (gnc:html-make-exchangerates
-                         report-commodity end-exchange-fn accounts)))
+		   (then (gnc:html-make-rates-table
+			  report-commodity start-price-fn accounts))
+		   (now (gnc:html-make-rates-table
+                         report-commodity end-price-fn accounts)))
 	      (gnc:html-table-set-col-headers! curr-tbl headers)
 	      (gnc:html-table-set-style!
 	       curr-tbl "table" 'attribute '("border" "1"))
